# -*- coding:Utf-8 -*-

# ==================================================
#  >> IMPORTATIONS                                 #
# ==================================================


import es
import langlib

import os
import re
import shelve
import datetime

import psyco
psyco.full()


# ==================================================
#  >> INFORMATIONS                                 #
# ==================================================


temp = {
   'name'       : 'Show-Damage',
   'version'    : '2.3',
   'date'       : '2010-04-10',
   'author'     : 'L\'In20Cible',
   'description': 'Annonce les dommages causés directement au milieu de son écran.',
   'url'        : 'http://addons.eventscripts.com/addons/view/showdamage',
   'basename'   : 'showdamage'
   }
   
informations = es.AddonInfo()
for information in temp:
   informations[information] = temp[information]
   
es.ServerVar('sd_version', (informations['version'] + ' by ' + informations['author'])).makepublic()


# ==================================================
#  >> INITIALISATION                               #
# ==================================================


def load():
   __init__()
   
   es.addons.registerSayFilter(SayFilterCallBack)
   
   
def __init__():
   global admins
   global players
   global options
   global settings
   global translations
   
   admins = list()
   filepath = GetConfigurationFilePath('admins.txt')
   if os.path.isfile(filepath):
      regex = re.compile('//.*|^(( |\t)+)|(( |\t)+)$|(\r)+|(\n)+')
      for fileline in open(filepath):
         fileline = regex.sub('', fileline).strip()
         if not fileline:
            continue
         admins.append(fileline)
         
   players = dict()
   
   options = {
      'enable'        : '1',
      'admins'        : '0',
      'status'        : '1',
      'advert'        : '1',
      'saycmd'        : '!ShowDamage',
      'saycmd_display': '1'
      }
   for option in options:
      options[option] = es.ServerVar(('sd_' + option), options[option])
   filepath = GetConfigurationFilePath('configuration.cfg')
   if os.path.isfile(filepath):
      es.mexec(filepath.replace(str(es.ServerVar('eventscripts_gamedir')), '..'))
      
   filepath = GetConfigurationFilePath('settings.db')
   settings = shelve.open(filepath, 'c', None, True)
   
   translations = TranslationsAreMissingCallBack
   filepath = GetConfigurationFilePath('translations.ini')
   if os.path.isfile(filepath):
      try:
         translations = langlib.Strings(filepath)
      except:
         pass
         
         
def unload():
   settings.close()
   es.addons.unregisterSayFilter(SayFilterCallBack)
   
   
# ==================================================
#  >> UTILITAIRES                                  #
# ==================================================


def GetConfigurationFilePath(filename):
   folderpath = os.path.join(es.getAddonPath(informations.basename), 'configuration').replace(os.sep, '/')
   if not os.path.isdir(folderpath):
      os.mkdir(folderpath)
   return os.path.join(es.getAddonPath(informations.basename), 'configuration', filename).replace(os.sep, '/')
   
   
def GetPlayerSteamID(userid):
   userid = int(userid)
   usersteamid = es.getplayersteamid(userid)
   if int(es.ServerVar('sv_lan')) or (usersteamid == 'STEAM_ID_LAN'):
      usersteamid = es.createplayerlist(userid)[userid]['address'].split(':')[0]
   return usersteamid
   
   
def ShowPlayerTotalDamage(userid):
   userid = int(userid)
   usersteamid = GetPlayerSteamID(userid)
   if ((usersteamid not in settings) and not int(options['status'])) or ((usersteamid in settings) and not settings[usersteamid]['status']) or (int(options['admins']) and usersteamid not in admins):
      return
   if (userid in players) and (players[userid] > 0):
      tokens = {
         'damages': str(players[userid])
         }
      es.tell(userid, '#multi', ('#green[Show-Damage] #default' + translations('showdamage', tokens, langlib.getLangAbbreviation(es.getclientvar(userid, 'cl_language')))))
   else:
      es.tell(userid, '#multi', ('#green[Show-Damage] #default' + translations('nodamage', dict(), langlib.getLangAbbreviation(es.getclientvar(userid, 'cl_language')))))
   
   
# ==================================================
#  >> FONCTIONS D'APPEL                            #
# ==================================================


def TranslationsAreMissingCallBack(string, tokens, language):
   return 'Sorry, unable to read the #lightgreentranslations.ini #defaultfile.'
   
   
def SayFilterCallBack(userid, string, teamonly):
   if int(options['enable']) and (str(options['saycmd']).lower() == string.lower().strip('"')):
      usersteamid = GetPlayerSteamID(userid)
      if usersteamid not in settings:
         settings[usersteamid] = {
            'status'  : True,
            'datetime': datetime.date.today()
            }
      if settings[usersteamid]['status']:
         settings[usersteamid]['status'] = False
      else:
         settings[usersteamid]['status'] = True
      userstatus = settings[usersteamid]['status']
      es.tell(userid, '#multi', ('#green[Show-Damage] #default' + translations('enable' if userstatus else 'disable', dict(), langlib.getLangAbbreviation(es.getclientvar(userid, 'cl_language')))))
      if not int(options['saycmd_display']):
         userid = 0
   return userid, string, teamonly
   
   
# ==================================================
#  >> ÉVÉNEMENTS                                   #
# ==================================================


def es_map_start(event_var):
   if settings:
      settings.close()
   __init__()
   if not len(settings):
      return
   for playersteamid in settings:
      if not (datetime.date.today() - settings[playersteamid]['datetime']).days >= 7:
         continue
      del settings[playersteamid]
   
   
def round_start(event_start):
   if not int(options['enable']):
      return
   if int(options['advert']):
      for playerid in es.getUseridList():
         if es.isbot(playerid):
            continue
         tokens = {
            'saycmd': str(options['saycmd']).lower()
            }
         es.tell(playerid, '#multi', ('#green[Show-Damage] #default' + translations('advert', tokens, langlib.getLangAbbreviation(es.getclientvar(playerid, 'cl_language')))))
         
         
def player_spawn(event_var):
   usersteamid = GetPlayerSteamID(event_var['userid'])
   if usersteamid not in settings:
      return
   settings[usersteamid]['datetime'] = datetime.date.today()
   
   
def round_end(event_var):
   if not int(options['enable']):
      return
   for playerid in es.getUseridList():
      if es.isbot(playerid) or es.getplayerprop(playerid, 'CBasePlayer.pl.deadflag'):
         continue
      ShowPlayerTotalDamage(playerid)
   for playerid in players:
      if not players[playerid] > 0:
         continue
      players[playerid] = 0
      
      
def player_death(event_var):
   if not int(options['enable']) or es.isbot(event_var['userid']):
      return
   ShowPlayerTotalDamage(event_var['userid'])
   
   
def player_hurt(event_var):
   attackerid = int(event_var['attacker'])
   if es.exists('userid', attackerid) and es.isbot(attackerid):
      return
   damage = int(event_var['dmg_health'])
   if attackerid not in players:
      players[attackerid] = damage
   else:
      players[attackerid] = (players[attackerid] + damage)
   if int(options['enable']):
      attackersteamid = GetPlayerSteamID(attackerid)
      if ((int(options['admins']) and attackersteamid in admins) or not int(options['admins'])) and (((attackersteamid not in settings) and int(options['status'])) or ((attackersteamid in settings) and settings[attackersteamid]['status'])):
         es.centertell(attackerid, ('-' + str(damage) + 'HP'))